@@ -1,5 +1,5 @@
 
-#  $Id: Pg.pm,v 1.65 2003/10/29 21:22:12 rlippan Exp $
+#  $Id: Pg.pm,v 1.67 2003/11/10 03:37:25 rlippan Exp $
 #
 #  Copyright (c) 1997,1998,1999,2000 Edmund Mergl
 #  Copyright (c) 2002 Jeffrey W. Baker
@@ -12,7 +12,7 @@
 
 use 5.006001;
 
-$DBD::Pg::VERSION = '1.31_7';
+$DBD::Pg::VERSION = '1.31_8';
 
 {
 	package DBD::Pg;
@@ -221,12 +221,9 @@ $DBD::Pg::VERSION = '1.31_7';
 		my $schemajoin = DBD::Pg::_pg_check_version(7.3, $version) ? 
 			"JOIN pg_catalog.pg_namespace n ON (n.oid = c.relnamespace)" : "";
 
-		my $pg_description_join = DBD::Pg::_pg_check_version(7.2, $version) ?
-		 	"LEFT JOIN ${CATALOG}pg_description d  ON (a.attnum = d.objsubid)\n".
-				"\t\t\t\tLEFT JOIN ${CATALOG}pg_class       dc ON (dc.oid = d.objoid )"
-					:
-						"LEFT JOIN ${CATALOG}pg_description d ON (a.oid = d.objoid )";
-		
+        my $remarks = DBD::Pg::_pg_check_version(7.2, $version) ?
+            "${CATALOG}col_description(a.attrelid, a.attnum)" : "NULL::text";
+
 		my $col_info_sql = qq!
 			SELECT
 				NULL::text AS "TABLE_CAT"
@@ -240,7 +237,7 @@ $DBD::Pg::VERSION = '1.31_7';
 				, NULL::text AS "DECIMAL_DIGITS"
 				, NULL::text AS "NUM_PREC_RADIX"
 				, CASE a.attnotnull WHEN 't' THEN 0 ELSE 1 END AS "NULLABLE"
-				, ${CATALOG}col_description(a.attrelid, a.attnum) AS "REMARKS"
+				, $remarks AS "REMARKS"
 				, af.adsrc AS "COLUMN_DEF"
 				, NULL::text AS "SQL_DATA_TYPE"
 				, NULL::text AS "SQL_DATETIME_SUB"
@@ -256,7 +253,6 @@ $DBD::Pg::VERSION = '1.31_7';
 				JOIN ${CATALOG}pg_class c ON (a.attrelid = c.oid)
 				LEFT JOIN ${CATALOG}pg_attrdef af ON (a.attnum = af.adnum AND a.attrelid = af.adrelid)
 				$schemajoin
-				$pg_description_join
 			WHERE
 				a.attnum >= 0
 				AND c.relkind IN ('r','v')
